function [deltaC,deltaP,gamma,thetaC,thetaP,vega,rhoC,rhoP]=bgreek(U,K,T,r,v)
%BGREEK The greek page, changing market indicators, in the Black (1976) model
%	for evaluating European options on futures contracts, where the option
%	is subject to stock type settlement. If options are subject to futures
%	type settlement, set r=0.
%
%	Syntax: [deltaC,deltaP,gamma,thetaC,thetaP,vega,rhoC,rhoP] = BGREEK(U,K,T,r,v)
%
%	U	- the price of the underlying futures contract
%	K	- the strike price
%	T	- the time to expiration in days
%	r	- the risk free interest rate in percent
%	v	- the annual volatility in percent
%
%	deltaC	- the delta of a call option
%	deltaP	- the delta of a put option
%	gamma	- the gamma of an option
%	thetaC	- the theta of a call option
%	thetaP	- the theta of a put option
%	vega	- the vega of an option
%	rhoC	- the rho of a call option
%	rhoP	- the rho of a put option

% Copyright (c) 1996-98 by Rafal Weron.
% Written by: R. Weron.

T=T/365;
r=r/100;
v=v/100;
e_rt=exp(-r.*T);
vt=v.*sqrt(T);
h=(log(U./K)./vt)+vt/2;

C= U.*e_rt.*normcdf(h) -K.*e_rt.*normcdf(h-vt);
P=-U.*e_rt.*normcdf(-h)+K.*e_rt.*normcdf(vt-h);

deltaC= e_rt.*normcdf(h);
deltaP=-e_rt.*normcdf(-h);
gamma =(e_rt.*normpdf(h))./(U.*vt);
thetaC=(v.*U.*e_rt.*normpdf(h)/2)./sqrt(T)+r.*K.*e_rt.*normcdf(h-vt)-r.*U.*e_rt.*normcdf(h);
thetaP=(v.*U.*e_rt.*normpdf(h)/2)./sqrt(T)-r.*K.*e_rt.*normcdf(vt-h)+r.*U.*e_rt.*normcdf(-h);
vega  =e_rt.*U.*sqrt(T).*normpdf(h);
rhoC  =-T.*C;
rhoP  =-T.*P;
